@@ -18,6 +18,8 @@ import zope.sqlalchemy
 
 # import or define all models here to ensure they are attached to the
 # Base.metadata prior to any initialization routines
+
+# flake8: noqa
 from .db import (
         Group,
         User,
@@ -31,8 +33,10 @@ from .db import (
         ApplicationSetting,
         DateTimeMode,
         ApiKey,
-        DownloadToken
-        ) # flake8: noqa
+        DownloadToken,
+        Service,
+        ServiceExecution
+        )
 
 # run configure_mappers after defining all of the models to ensure
 # all relationships can be setup
@@ -49,7 +53,7 @@ def get_session_factory(engine):
     return factory
 
 
-def get_tm_session(session_factory, transaction_manager):
+def get_tm_session(session_factory, transaction_manager, **kwargs):
     """
     Get a ``sqlalchemy.orm.Session`` instance backed by a transaction.
 
@@ -70,7 +74,7 @@ def get_tm_session(session_factory, transaction_manager):
               dbsession = get_tm_session(session_factory, transaction.manager)
 
     """
-    dbsession = session_factory()
+    dbsession = session_factory(**kwargs)
     zope.sqlalchemy.register(
         dbsession, transaction_manager=transaction_manager)
     return dbsession
